abacusai.data_upload_result — AbacusAI documentation

# abacusai.data_upload_result

## Classes

`DataUploadResult` | Results of uploading data to agent.

## Module Contents

class abacusai.data_upload_result.DataUploadResult(client, docInfos=None, maxCount=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Results of uploading data to agent.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docInfos (list[agentdatadocumentinfo]) – A list of dict for information on the documents uploaded to agent.

    - maxCount (int) – The maximum number of documents

  doc_infos
  max_count
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict